networkinference.utils.tools.FakeData
=====================================

.. currentmodule:: networkinference.utils.tools

.. autoclass:: FakeData
   :members:
   :show-inheritance:
   :inherited-members: